# Candango Coelho AMPQ Toolkit

Coelho is a AMPQ Toolkit based on pika developed by Candango Open Source Group.

The objective of this project is provide easy to use tools to design AMPQ based
applications that runs over Firenado and Tornado frameworks.

## What Coelho means?

The word coelho(kuh-way-lee-ou) is rabbit in Portuguese.

## License

**Apache License V2.0**

Copyright © 2019-2020 Flavio Garcia
